cML_estimate_DP: Estimate with With Data Perturbation

View source: R/cML_estimate_DP.R

cML_estimate_DPR Documentation

Estimate with With Data Perturbation

Description

With multiple perturbed data, get estimated theta, se of estimated theta and negative log-likelihood, using multiple random starting points.

Usage

cML_estimate_DP(
  b_exp,
  b_out,
  se_exp,
  se_out,
  K,
  num_pert = 200,
  random_start = 0,
  maxit = 100
)

Arguments

b_exp

Vector of estimated effects for exposure.

b_out

Vector or estimated effects for outcome.

se_exp

Vector of standard errors for exposure.

se_out

Vector of standard errors for outcome.

K

Constraint parameter, number of invalid IVs.

num_pert

Number of perturbation, default is 200.

random_start

Number of random starting points, default is 0.

maxit

Maximum number of iteration.

Value

A list contains: theta_v is the vector estimated thetas, se_v is vector of standard errors of estimated thetas, l_v is vector of negative log-likelihood. Vectors all have length num_pert.


xue-hr/MRcML documentation built on Aug. 25, 2024, 4:24 p.m.